@@ -1,7 +1,7 @@
 /*
  *  OpenSlide, a library for reading whole slide image files
  *
- *  Copyright (c) 2007-2012 Carnegie Mellon University
+ *  Copyright (c) 2007-2013 Carnegie Mellon University
  *  Copyright (c) 2011 Google, Inc.
  *  All rights reserved.
  *
@@ -82,7 +82,7 @@ static void warning_callback(const char *msg G_GNUC_UNUSED,
 }
 static void error_callback(const char *msg, void *data) {
   openslide_t *osr = data;
-  _openslide_set_error(osr, "%s", msg);
+  _openslide_set_error(osr, "OpenJPEG error: %s", msg);
 }
 
 static void copy_aperio_tile(uint16_t compression_mode,
@@ -167,6 +167,14 @@ static void aperio_tiff_tilereader(openslide_t *osr,
   }
   tsize_t tile_size = sizes[tile_no];
 
+  // a slide with zero-length tiles has been seen in the wild
+  if (!tile_size) {
+    // fill with transparent
+    memset(dest, 0, w * h * 4);
+    //g_debug("skipping tile %d", tile_no);
+    return;  // ok, haven't allocated anything yet
+  }
+
   // get raw tile
   tdata_t buf = g_slice_alloc(tile_size);
   tsize_t size = TIFFReadRawTile(tiff, tile_no, buf, tile_size);
